@@ -1,6 +1,9 @@
 import cffi
-import cPickle as pickle
-from os.path import join, dirname, exists
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
+from os.path import join, dirname
 
 ffi = cffi.FFI()
 
@@ -2072,11 +2075,34 @@ def _parse():
     ffi.cdef(''.join(_cdefs))
     return ffi
 
-cachefile = join(dirname(__file__), 'cdefs.pickle')
-try:
-    with open(cachefile, 'rb') as pickled:
-        ffi._parser, ffi._cdefsources = pickle.load(pickled)
-except:
+
+# remove/restore unpickleable WeakKeyDictionary()
+def _parser_save(parser):
+    parser._structnode2type = {}
+    return parser
+
+def _parser_restore(parser):
+    if not hasattr(parser, '_structnode2type'):
+        import weakref
+        parser._structnode2type = weakref.WeakKeyDictionary()
+
+
+nocache = False
+if nocache:
     ffi = _parse()
-    with open(cachefile, 'wb+') as pickled:
-        pickle.dump((ffi._parser, ffi._cdefsources), pickled)
+else:
+    import os, sys
+    cachedir = join(dirname(__file__), '__pycache__')
+    if not os.path.exists(cachedir):
+        os.mkdir(cachedir)
+    cachefile = join(cachedir, 'cdefs_py%d%d.pickle' % sys.version_info[:2])
+    try:
+        with open(cachefile, 'rb') as pickled:
+            ffi._parser, ffi._cdefsources = pickle.load(pickled)
+            _parser_restore(ffi._parser)
+    except:
+        ffi = _parse()
+        with open(cachefile, 'wb+') as pickled:
+            _parser_save(ffi._parser)
+            pickle.dump((ffi._parser, ffi._cdefsources), pickled)
+            _parser_restore(ffi._parser)
