@@ -6,8 +6,7 @@ from _sdl_ttf import lib
 
 __all__ = []
 
-def _init():
-    here = globals()
+def _mapping():
     import re
     constant_re = re.compile("TTF_(?P<pretty_name>[A-Z][A-Z].+)$")
     renamer = _sdl.renamer.Renamer(lib, "TTF_", constant_re)
@@ -16,8 +15,13 @@ def _init():
         pretty_name = renamer.rename(name, value)
         if not pretty_name:
             continue
-        here[pretty_name] = value
-        __all__.append(pretty_name)
-        __all__.sort()
+        yield name, pretty_name
 
-_init()
\ No newline at end of file
+def _init():
+    here = globals()
+    for name, pretty_name in _mapping():
+        here[pretty_name] = getattr(lib, name)
+        __all__.append(pretty_name)
+    __all__.sort()
+
+_init()
